==> dotup_flutter_logger_sqflite_writer-0.0.1.tar.gz: dotup_example/lib/main.dart <==
import 'dart:io';

import 'package:dotup_dart_logger/dotup_dart_logger.dart';
import 'package:dotup_flutter_logger/dotup_flutter_logger.dart';
import 'package:dotup_flutter_logger_sqflite_writer/dotup_flutter_logger_sqflite_writer.dart';
import 'package:flutter/material.dart';
import 'package:path_provider/path_provider.dart';
import 'package:uuid/uuid.dart';

late final SqfLiteLogWriter sqfLiteLogWriter;

final logger = Logger('cool');

void main() {
  WidgetsFlutterBinding.ensureInitialized();
  mainAsync();
}

Future<void> mainAsync() async {
  var dir = await getApplicationDocumentsDirectory();
  final dbFolder = dir.path;

  if (!await Directory(dbFolder).exists()) {
    await Directory(dbFolder).create(recursive: true);
  }

  final databaseFile = '$dbFolder/logging.db';

  // final rm = await Bootstrapper().initialize(databaseFile);
  // final repo = rm.getRepository<LoggerRepository>()!;
  // final newId = Uuid().v4();
  // final item = LoggerEntity(logLevel: LogLevel.Debug, message: 'message', id: newId, timeStamp: DateTime.now());
  // repo.create(item);
  // final all = await repo.readAll();
  // for (var item in all) {
  //   print(item.message);
  // }
  sqfLiteLogWriter = SqfLiteLogWriter(LogLevel.All);
  await sqfLiteLogWriter.initialize(databaseFile);
  LoggerManager.addLogWriter(sqfLiteLogWriter);
  runApp(MyApp());
}

class MyApp extends StatelessWidget {
  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'dotup.de Logger Demo',
      theme: ThemeData(
        // This is the theme of your application.
        //
        // Try running your application with "flutter run". You'll see the
        // application has a blue toolbar. Then, without quitting the app, try
        // changing the primarySwatch below to Colors.green and then invoke
        // "hot reload" (press "r" in the console where you ran "flutter run",
        // or simply save your changes to "hot reload" in a Flutter IDE).
        // Notice that the counter didn't reset back to zero; the application
        // is not restarted.
        primarySwatch: Colors.blue,
      ),
      home: MyHomePage(title: 'dotup.de Logger Demo'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  MyHomePage({Key? key, required this.title}) : super(key: key);

  // This widget is the home page of your application. It is stateful, meaning
  // that it has a State object (defined below) that contains fields that affect
  // how it looks.

  // This class is the configuration for the state. It holds the values (in this
  // case the title) provided by the parent (in this case the App widget) and
  // used by the build method of the State. Fields in a Widget subclass are
  // always marked "final".

  final String title;

  @override
  _MyHomePageState createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  late final LoggerLiveController controller;

  @override
  void initState() {
    controller = LoggerLiveController(20);
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    // This method is rerun every time setState is called, for instance as done
    // by the _incrementCounter method above.
    //
    // The Flutter framework has been optimized to make rerunning build methods
    // fast, so that you can just rebuild anything that needs updating rather
    // than having to individually change instances of widgets.
    return Scaffold(
      appBar: AppBar(
        // Here we take the value from the MyHomePage object that was created by
        // the App.build method, and use it to set our appbar title.
        title: Text(widget.title),
      ),
      body: Center(
          // Center is a layout widget. It takes a single child and positions it
          // in the middle of the parent.
          child: LoggerView(
        loggerListController: controller,
      )),
      floatingActionButton: FloatingActionButton(
        onPressed: () {
          // final logEntry = LogEntry(logLevel: LogLevel.Debug, message: 'message');
          // sqfLiteLogWriter.write(logEntry);
          logger.debug('DEBUGGY');
          logger.info('Important info');
          // setState(() {
          //   controller.toggleNotifier();
          // });
        },
        tooltip: 'Create',
        child: controller.isNotifing ? Icon(Icons.pause) : Icon(Icons.play_arrow),
      ), // This trailing comma makes auto-formatting nicer for build methods.
    );
  }
}

==> dotup_flutter_logger_sqflite_writer-0.2.0.tar.gz: dotup_example/lib/main.dart <==
import 'dart:io';

import 'package:dotup_dart_logger/dotup_dart_logger.dart';
import 'package:dotup_flutter_logger/dotup_flutter_logger.dart';
import 'package:dotup_flutter_logger_sqflite_writer/dotup_flutter_logger_sqflite_writer.dart';
import 'package:flutter/material.dart';
import 'package:path_provider/path_provider.dart';
import 'package:uuid/uuid.dart';

late final SqfLiteLogWriter sqfLiteLogWriter;

final logger = Logger('cool');

void main() {
  WidgetsFlutterBinding.ensureInitialized();
  mainAsync();
}

Future<void> mainAsync() async {
  var dir = await getApplicationDocumentsDirectory();
  final dbFolder = dir.path;

  if (!await Directory(dbFolder).exists()) {
    await Directory(dbFolder).create(recursive: true);
  }

  final databaseFile = '$dbFolder/logging.db';

  // final rm = await Bootstrapper().initialize(databaseFile);
  // final repo = rm.getRepository<LoggerRepository>()!;
  // final newId = Uuid().v4();
  // final item = LoggerEntity(logLevel: LogLevel.Debug, message: 'message', id: newId, timeStamp: DateTime.now());
  // repo.create(item);
  // final all = await repo.readAll();
  // for (var item in all) {
  //   print(item.message);
  // }
  sqfLiteLogWriter = SqfLiteLogWriter(LogLevel.All);
  await sqfLiteLogWriter.initialize(databaseFile);
  LoggerManager.addLogWriter(sqfLiteLogWriter);
  runApp(MyApp());
}

class MyApp extends StatelessWidget {
  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'dotup.de Logger Demo',
      theme: ThemeData(
        // This is the theme of your application.
        //
        // Try running your application with "flutter run". You'll see the
        // application has a blue toolbar. Then, without quitting the app, try
        // changing the primarySwatch below to Colors.green and then invoke
        // "hot reload" (press "r" in the console where you ran "flutter run",
        // or simply save your changes to "hot reload" in a Flutter IDE).
        // Notice that the counter didn't reset back to zero; the application
        // is not restarted.
        primarySwatch: Colors.blue,
      ),
      home: MyHomePage(title: 'dotup.de Logger Demo'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  MyHomePage({Key? key, required this.title}) : super(key: key);

  // This widget is the home page of your application. It is stateful, meaning
  // that it has a State object (defined below) that contains fields that affect
  // how it looks.

  // This class is the configuration for the state. It holds the values (in this
  // case the title) provided by the parent (in this case the App widget) and
  // used by the build method of the State. Fields in a Widget subclass are
  // always marked "final".

  final String title;

  @override
  _MyHomePageState createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  late final LoggerListController controller;

  @override
  void initState() {
    controller = LoggerListController(20);
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    // This method is rerun every time setState is called, for instance as done
    // by the _incrementCounter method above.
    //
    // The Flutter framework has been optimized to make rerunning build methods
    // fast, so that you can just rebuild anything that needs updating rather
    // than having to individually change instances of widgets.
    return Scaffold(
      appBar: AppBar(
        // Here we take the value from the MyHomePage object that was created by
        // the App.build method, and use it to set our appbar title.
        title: Text(widget.title),
      ),
      body: Center(
          // Center is a layout widget. It takes a single child and positions it
          // in the middle of the parent.
          child: LoggerView(
        loggerListController: controller,
      )),
      floatingActionButton: FloatingActionButton(
        onPressed: () {
          // final logEntry = LogEntry(logLevel: LogLevel.Debug, message: 'message');
          // sqfLiteLogWriter.write(logEntry);
          logger.debug('DEBUGGY');
          logger.info('Important info');
          // setState(() {
          //   controller.toggleNotifier();
          // });
        },
        tooltip: 'Create',
        child: controller.isNotifing ? Icon(Icons.pause) : Icon(Icons.play_arrow),
      ), // This trailing comma makes auto-formatting nicer for build methods.
    );
  }
}
